# TODO Build database of regions and get the rss directly for the region
#      For now, just for big countries!

regions = {
    "AT": {},
    "BA": {},
    "BE": {},
    "BG": {},
    "CH": {},
    "CY": {},
    "CZ": {},
    "DE": {
"Alb-Donau-Kreis und Stadt Ulm":"074",
"Altmarkkreis Salzwedel":"216",
"B.gau-Hochschwarzwald / Freiburg":"035",
"Bodenseekreis":"271",
"Bundesstadt Bonn":"289",
"Burgenlandkreis":"145",
"Darmstadt-Dieburg / Darmstadt":"047",
"Donnersbergkreis":"197",
"Eifelkreis Bitburg-Prüm":"387",
"Ennepe-Ruhr-Kreis":"134",
"Enzkreis und Stadt Pforzheim":"050",
"Erzgebirgskreis":"343",
"Hansestadt Bremen":"369",
"Hansestadt Hamburg":"413",
"Hansestadt Lübeck":"265",
"Hansestadt Rostock":"234",
"Heidekreis":"317",
"Hochsauerlandkreis":"411",
"Hochtaunuskreis":"201",
"Hohenlohekreis":"212",
"Ilm-Kreis":"254",
"Kreis Ahrweiler":"232",
"Kreis Aichach-Friedberg":"375",
"Kreis Altenburger Land":"255",
"Kreis Altenkirchen":"199",
"Kreis Altötting":"116",
"Kreis Alzey-Worms":"397",
"Kreis Amberg-Sulzbach":"353",
"Kreis Anhalt-Bitterfeld":"357",
"Kreis Bad Dürkheim":"390",
"Kreis Bad Kissingen":"409",
"Kreis Bad Kreuznach":"143",
"Kreis Bad Tölz-Wolfratshausen":"371",
"Kreis Barnim":"264",
"Kreis Bautzen - Bergland":"086",
"Kreis Bautzen - Tiefland":"054",
"Kreis Berchtesgadener Land":"183",
"Kreis Bergstraße":"361",
"Kreis Bernkastel-Wittlich":"190",
"Kreis Biberach":"163",
"Kreis Birkenfeld":"182",
"Kreis Böblingen":"223",
"Kreis Börde":"306",
"Kreis Borken":"355",
"Kreis Calw":"152",
"Kreis Celle":"138",
"Kreis Cham":"309",
"Kreis Cochem-Zell":"214",
"Kreis Coesfeld":"125",
"Kreis Cuxhaven - Binnenland":"030",
"Kreis Cuxhaven - Küste":"045",
"Kreis Dachau":"414",
"Kreis Dahme-Spreewald":"172",
"Kreis Deggendorf":"117",
"Kreis Diepholz":"310",
"Kreis Dillingen a.d. Donau":"354",
"Kreis Dingolfing-Landau":"251",
"Kreis Dithmarschen - Binnenland":"081",
"Kreis Dithmarschen - Küste":"091",
"Kreis Donau-Ries":"147",
"Kreis Düren":"314",
"Kreis Ebersberg":"260",
"Kreis Eichsfeld":"406",
"Kreis Eichstätt":"303",
"Kreis Elbe-Elster":"261",
"Kreis Emmendingen":"227",
"Kreis Erding":"339",
"Kreis Erlangen-Höchstadt":"196",
"Kreis Esslingen":"302",
"Kreis Euskirchen":"127",
"Kreis Forchheim":"191",
"Kreis Freising":"374",
"Kreis Freudenstadt":"404",
"Kreis Freyung-Grafenau":"380",
"Kreis Fulda":"248",
"Kreis Fürstenfeldbruck":"379",
"Kreis Garmisch-Partenkirchen":"195",
"Kreis Germersheim":"153",
"Kreis Gießen":"185",
"Kreis Gifhorn":"244",
"Kreis Göppingen":"215",
"Kreis Görlitz - Bergland":"070",
"Kreis Görlitz - Tiefland":"075",
"Kreis Goslar":"328",
"Kreis Gotha":"193",
"Kreis Göttingen":"151",
"Kreis Greiz":"352",
"Kreis Groß-Gerau":"166",
"Kreis Günzburg":"388",
"Kreis Gütersloh":"119",
"Kreis Hameln-Pyrmont":"111",
"Kreis Hamm":"159",
"Kreis Harburg":"170",
"Kreis Harz - Bergland":"093",
"Kreis Harz - Tiefland":"048",
"Kreis Haßberge":"335",
"Kreis Havelland":"382",
"Kreis Heidenheim":"311",
"Kreis Heinsberg":"157",
"Kreis Helmstedt":"415",
"Kreis Herford":"365",
"Kreis Hersfeld-Rotenburg":"217",
"Kreis Herzogtum Lauenburg":"236",
"Kreis Hildburghausen":"305",
"Kreis Hildesheim":"384",
"Kreis Holzminden":"176",
"Kreis Höxter":"327",
"Kreis Jerichower Land":"141",
"Kreis Kelheim":"165",
"Kreis Kitzingen":"399",
"Kreis Kleve":"283",
"Kreis Konstanz":"419",
"Kreis Kronach":"296",
"Kreis Kulmbach":"245",
"Kreis Kusel":"160",
"Kreis Landsberg am Lech":"130",
"Kreis Leipzig":"179",
"Kreis Lichtenfels":"178",
"Kreis Limburg-Weilburg":"341",
"Kreis Lindau":"280",
"Kreis Lippe":"407",
"Kreis Lörrach":"312",
"Kreis Lüchow-Dannenberg":"122",
"Kreis Ludwigsburg":"241",
"Kreis Ludwigslust-Parchim - Ost":"076",
"Kreis Ludwigslust-Parchim - West":"107",
"Kreis Lüneburg":"383",
"Kreis Main-Spessart":"304",
"Kreis Mainz-Bingen / Mainz":"097",
"Kreis Mansfeld-Südharz":"180",
"Kreis Marburg-Biedenkopf":"362",
"Kreis Märkisch-Oderland":"233",
"Kreis Mayen-Koblenz":"351",
"Kreis Meißen":"416",
"Kreis Merzig-Wadern":"137",
"Kreis Mettmann":"250",
"Kreis Miesbach":"293",
"Kreis Miltenberg":"266",
"Kreis Minden-Lübbecke":"131",
"Kreis Mittelsachsen - Bergland":"099",
"Kreis Mittelsachsen - Tiefland":"094",
"Kreis Mühldorf a. Inn":"332",
"Kreis Neuburg-Schrobenhausen":"402",
"Kreis Neumarkt i.d. OPf.":"219",
"Kreis Neunkirchen":"274",
"Kreis Neustadt a.d. Waldnaab":"321",
"Kreis Neu-Ulm":"348",
"Kreis Neuwied":"270",
"Kreis Nienburg":"298",
"Kreis Nordfriesland - Binnenland":"106",
"Kreis Nordfriesland - Küste":"095",
"Kreis Nordhausen":"373",
"Kreis Nordsachsen - Nord":"028",
"Kreis Nordsachsen - Süd":"071",
"Kreis Northeim":"294",
"Kreis Nürnberger Land":"358",
"Kreis Oberallgäu":"330",
"Kreis Oberhavel":"322",
"Kreis Oberspreewald-Lausitz":"140",
"Kreis Oder-Spree":"242",
"Kreis Olpe":"229",
"Kreis Ostallgäu":"239",
"Kreis Osterholz":"209",
"Kreis Osterode am Harz":"326",
"Kreis Ostholstein - Binnenland":"073",
"Kreis Ostholstein - Küste":"061",
"Kreis Ostprignitz-Ruppin":"313",
"Kreis Paderborn":"324",
"Kreis Peine":"257",
"Kreis Pfaffenhofen a.d. Ilm":"420",
"Kreis Pinneberg":"058",
"Kreis Plön - Binnenland":"088",
"Kreis Plön - Küste":"037",
"Kreis Potsdam-Mittelmark":"187",
"Kreis Prignitz":"247",
"Kreis Rastatt":"146",
"Kreis Ravensburg":"344",
"Kreis Recklinghausen":"224",
"Kreis Regen":"391",
"Kreis Reutlingen":"276",
"Kreis Rhön-Grabfeld":"121",
"Kreis Rostock - Binnenland Nord":"036",
"Kreis Rostock - Binnenland Süd":"027",
"Kreis Rostock - Küste":"055",
"Kreis Rotenburg (Wümme)":"142",
"Kreis Roth":"338",
"Kreis Rottal-Inn":"421",
"Kreis Rottweil":"285",
"Kreis Saalfeld-Rudolstadt":"115",
"Kreis Saarlouis":"240",
"Kreis Schaumburg":"225",
"Kreis Schmalkalden-Meiningen":"203",
"Kreis Schwäbisch Hall":"340",
"Kreis Schwandorf":"112",
"Kreis Segeberg":"181",
"Kreis Siegen-Wittgenstein":"269",
"Kreis Sigmaringen":"320",
"Kreis Soest":"155",
"Kreis Sömmerda":"323",
"Kreis Sonneberg":"206",
"Kreis Spree-Neiße":"129",
"Kreis Stade":"222",
"Kreis Starnberg":"267",
"Kreis Steinburg":"158",
"Kreis Steinfurt":"273",
"Kreis Stendal":"325",
"Kreis Stormarn":"400",
"Kreis St. Wendel":"136",
"Kreis Südliche Weinstraße":"405",
"Kreis Südwestpfalz / Pirmasens":"098",
"Kreis Teltow-Fläming":"345",
"Kreis Tirschenreuth":"398",
"Kreis Traunstein":"288",
"Kreis Trier-Saarburg / Trier":"051",
"Kreis Tübingen":"301",
"Kreis Tuttlingen":"175",
"Kreis Uckermark":"144",
"Kreis Uelzen":"350",
"Kreis und Stadt Ansbach":"078",
"Kreis und Stadt Aschaffenburg":"057",
"Kreis und Stadt Augsburg":"096",
"Kreis und Stadt Bamberg":"046",
"Kreis und Stadt Bayreuth":"042",
"Kreis und Stadt Coburg":"087",
"Kreis und Stadt Fürth":"020",
"Kreis und Stadt Heilbronn":"080",
"Kreis und Stadt Hof":"089",
"Kreis und Stadt Kaiserslautern":"084",
"Kreis und Stadt Karlsruhe":"109",
"Kreis und Stadt Kassel":"026",
"Kreis und Stadt Landshut":"021",
"Kreis und Stadt München":"056",
"Kreis und Stadt Offenbach":"041",
"Kreis und Stadt Oldenburg":"079",
"Kreis und Stadt Passau":"066",
"Kreis und Stadt Regensburg":"049",
"Kreis und Stadt Rosenheim":"029",
"Kreis und Stadt Schweinfurt":"105",
"Kreis und Stadt Würzburg":"077",
"Kreis Unna":"235",
"Kreis Unterallgäu":"249",
"Kreis Verden":"393",
"Kreis Viersen":"113",
"Kreis Vulkaneifel":"356",
"Kreis Waldeck-Frankenberg":"218",
"Kreis Waldshut":"281",
"Kreis Warendorf":"171",
"Kreis Weilheim-Schongau":"342",
"Kreis Weimarer Land":"194",
"Kreis Weißenburg-Gunzenhausen":"410",
"Kreis Wesel":"253",
"Kreis Wesermarsch - Binnenland":"064",
"Kreis Wesermarsch - Küste":"101",
"Kreis Wittenberg":"263",
"Kreis Wolfenbüttel":"220",
"Kreis Wunsiedel":"213",
"Kreis Zwickau - Bergland":"044",
"Kreis Zwickau - Tiefland":"040",
"Kyffhäuserkreis":"262",
"Lahn-Dill-Kreis":"395",
"Main-Kinzig-Kreis":"118",
"Main-Tauber-Kreis":"308",
"Main-Taunus-Kreis":"412",
"Märkischer Kreis":"389",
"Mecklenburg. Seenplatte - Mitte":"025",
"Mecklenburg. Seenplatte - Südost":"082",
"Mecklenburg. Seenplatte - West":"059",
"Neckar-Odenwald-Kreis":"290",
"Neustadt/Aisch - Bad Windsheim":"372",
"Nordwestmecklenburg - Binnenland":"085",
"Nordwestmecklenburg - Küste":"033",
"Oberbergischer Kreis":"243",
"Odenwaldkreis":"360",
"Ortenaukreis":"329",
"Ostalbkreis":"346",
"Regionalverband Saarbrücken":"189",
"Region Hannover":"169",
"Rems-Murr-Kreis":"284",
"Rendsburg-Eckernförde - Binnenl.":"031",
"Rendsburg-Eckernförde - Küste":"067",
"Rhein-Erft-Kreis":"367",
"Rheingau-Taunus-Kreis":"268",
"Rhein-Hunsrück-Kreis":"292",
"Rheinisch-Bergischer Kreis":"366",
"Rhein-Kreis Neuss":"164",
"Rhein-Lahn-Kreis":"300",
"Rhein-Neckar-Kreis / Heidelberg":"110",
"Rhein-Pfalz-Kreis / Ludwigshafen":"068",
"Rhein-Sieg-Kreis":"198",
"Saale-Holzland-Kreis":"386",
"Saalekreis":"204",
"Saale-Orla-Kreis":"318",
"Saarpfalz-Kreis":"238",
"Sächs. Schweiz-Osterzgeb.-ö. Bgl":"063",
"Sächs. Schweiz-Osterzgeb.-Tiefl.":"038",
"Sächs. Schweiz-Osterzgeb.-w. Bgl":"092",
"Salzlandkreis":"228",
"Schleswig-Flensburg - Binnenland":"062",
"Schleswig-Flensburg - Küste":"060",
"Schwalm-Eder-Kreis":"177",
"Schwarzwald-Baar-Kreis":"408",
"Stadt Amberg":"205",
"Stadt Baden-Baden":"347",
"Stadt Berlin":"202",
"Stadt Bielefeld":"378",
"Stadt Bochum":"396",
"Stadt Bottrop":"295",
"Stadt Brandenburg":"392",
"Stadt Braunschweig":"275",
"Stadt Bremerhaven":"173",
"Stadt Chemnitz":"297",
"Stadt Cottbus":"394",
"Stadt Delmenhorst":"337",
"Stadt Dessau-Roßlau":"259",
"Stadt Dortmund":"230",
"Stadt Dresden":"363",
"Stadt Duisburg":"336",
"Stadt Düsseldorf":"128",
"Stadt Eisenach":"286",
"StädteRegion Aachen":"258",
"Stadt Erfurt":"359",
"Stadt Erlangen":"139",
"Stadt Essen":"364",
"Stadt Flensburg":"156",
"Stadt Frankenthal":"370",
"Stadt Frankfurt am Main":"133",
"Stadt Frankfurt (Oder)":"272",
"Stadt Gelsenkirchen":"161",
"Stadt Gera":"162",
"Stadt Hagen":"291",
"Stadt Halle (Saale)":"135",
"Stadt Herne":"211",
"Stadt Ingolstadt":"282",
"Stadt Jena":"417",
"Stadt Kaufbeuren":"120",
"Stadt Kempten (Allgäu)":"381",
"Stadt Kiel":"418",
"Stadt Koblenz":"277",
"Stadt Köln":"299",
"Stadt Krefeld":"377",
"Stadt Landau in der Pfalz":"368",
"Stadt Leipzig":"126",
"Stadt Leverkusen":"256",
"Stadt Magdeburg":"278",
"Stadt Memmingen":"174",
"Stadt Mönchengladbach":"114",
"Stadt Mülheim an der Ruhr":"132",
"Stadt Münster":"167",
"Stadt Neumünster":"192",
"Stadt Neustadt an der Weinstraße":"210",
"Stadt Nürnberg":"150",
"Stadt Oberhausen":"401",
"Stadt Potsdam":"385",
"Stadt Remscheid":"252",
"Stadt Salzgitter":"334",
"Stadt Schwabach":"246",
"Stadt Schwerin":"331",
"Stadt Solingen":"186",
"Stadt Stuttgart":"226",
"Stadt Suhl":"208",
"Stadt Weiden in der Oberpfalz":"316",
"Stadt Weimar":"307",
"Stadt Wiesbaden":"403",
"Stadt Wolfsburg":"319",
"Stadt Worms":"333",
"Stadt Wuppertal":"207",
"Stadt Zweibrücken":"349",
"Straubing-Bogen / Straubing":"043",
"Unstrut-Hainich-Kreis":"123",
"Vogelsbergkreis":"315",
"Vogtlandkreis - Bergland":"023",
"Vogtlandkreis - Tiefland":"108",
"Vorpommern-Greifsw. - Binnenl. N":"022",
"Vorpommern-Greifsw. - Binnenl. S":"034",
"Vorpommern-Greifsw. - Küste Nord":"072",
"Vorpommern-Greifsw. - Küste Süd":"100",
"Vorpommern-Rügen - Binnenland":"090",
"Vorpommern-Rügen - Insel Rügen":"052",
"Vorpommern-Rügen - Küste":"032",
"Wartburgkreis":"149",
"Werra-Meissner-Kreis":"279",
"Westerwaldkreis":"148",
"Wetteraukreis":"231",
"Zollernalbkreis":"168",
    },
    "DK": {},
    "EE": {},
    "ES": {
"Albarracín y Jiloca":"102",
"Alcaraz y Segura":"162",
"Alcarria conquense":"168",
"Alcarria de Guadalajara":"173",
"A Mariña":"206",
"Campiña cordobesa":"079",
"Cantabria del Ebro":"136",
"Centro y valle de Villaverde":"135",
"Cordillera Cantábrica de Burgos":"140",
"Cordillera Cantábrica de León":"145",
"Cordillera Cantábrica de Palencia":"148",
"Cordillera y Picos de Europa":"112",
"Costa - A Mariña":"845",
"Costa - Menorca":"878",
"Costa - Miño de Pontevedra":"850",
"Costa - Noroeste de A Coruña":"846",
"Costa - Oeste de A Coruña":"847",
"Costa - Rias Baixas":"849",
"Costa - Suroeste de A Coruña":"848",
"Cuenca del Genil":"081",
"Cuenca del Nervión":"230",
"Guadix y Baza":"082",
"Ibérica de Burgos":"144",
"Ibérica de Soria":"155",
"Ibérica riojana":"238",
"Ibérica zaragozana":"106",
"Interior de A Coruña":"204",
"Interior de Pontevedra":"216",
"Interior norte de Valencia":"246",
"La Mancha albaceteña":"161",
"La Mancha conquense":"170",
"La Mancha toledana":"177",
"Liébana":"134",
"Meseta de Ávila":"137",
"Meseta de Burgos":"143",
"Meseta de León":"147",
"Meseta de Palencia":"149",
"Meseta de Salamanca":"150",
"Meseta de Segovia":"153",
"Meseta de Soria":"156",
"Meseta de Valladolid":"158",
"Meseta de Zamora":"160",
"Metropolitana y Henares":"219",
"Miño de Pontevedra":"217",
"Montaña de Lugo":"208",
"Montaña de Ourense":"213",
"Noroeste de A Coruña":"202",
"Norte de Burgos":"141",
"Oeste de A Coruña":"203",
"Parameras de Molina":"172",
"Pirineo de Lleida":"187",
"Pirineo oscense":"099",
"Rias Baixas":"215",
"Ribera del Ebro de La Rioja":"237",
"Sanabria":"159",
"Serranía de Cuenca":"169",
"Serranía de Guadalajara":"171",
"Sistema Central de Ávila":"138",
"Sistema Central de Salamanca":"151",
"Sistema Central de Segovia":"154",
"Sistema Central de Soria":"157",
"Sur de Mallorca":"117",
"Suroccidental asturiana":"110",
"Suroeste de A Coruña":"205",
"Sur, Vegas y Oeste":"220",
"Valle de Arán":"186",
"Valle del Tajo":"175",
"Vertiente cantábrica de Navarra":"226",
},
    "FI": {},
    "FR": {
"Ain":"039",
"Aisne":"073",
"Allier":"043",
"Andorre":"001",
"Ardennes":"074",
"Ariège":"008",
"Aube":"075",
"Bas Rhin":"086",
"Corse du Sud":"090",
"Côte d'Or":"078",
"Doubs":"080",
"Haute Corse":"089",
"Haute Garonne":"009",
"Haute Marne":"085",
"Hautes Alpes":"033",
"Haute Saône":"082",
"Haute Savoie":"035",
"Hautes Pyrénées":"003",
"Haut Rhin":"083",
"Isère":"034",
"Jura":"079",
"Marne":"076",
"Meurthe et Moselle":"088",
"Meuse":"002",
"Moselle":"087",
"Nièvre":"060",
"Nord":"070",
"Oise":"072",
"Pas de Calais":"069",
"Puy de Dôme":"040",
"Pyrénées Atlantiques":"091",
"Pyrénées Orientales":"006",
"Rhône":"038",
"Saône et Loire":"077",
"Savoie":"036",
"Territoire de Belfort":"081",
"Vosges":"084",
"Yonne":"062",
},
    "GR": {},
    "HR": {},
    "HU": {},
    "IE": {},
    "IL": {},
    "IS": {},
    "IT": {
"Calabria":"001",
"Emilia e Romagna":"008",
"Lombardia":"003",
"Piemonte":"005",
"Sicilia":"018",
"Veneto":"006",
},
    "LT": {},
    "LU": {},
    "LV": {},
    "MD": {},
    "ME": {},
    "MK": {},
    "MT": {},
    "NL": {},
    "NO": {},
    "PL": {},
    "PT": {},
    "RO": {},
    "RS": {},
    "SE": {},
    "SI": {},
    "SK": {},
    "UK": {},
}


awt = {
    "1": "Wind",
    "2": "Snow/Ice",
    "3": "Thunderstorms",
    "4": "Fog",
    "5": "Extreme high temperature",
    "6": "Extreme low temperature",
    "7": "Coastal Event",
    "8": "Forestfire",
    "9": "Avalanches",
    "10": "Rain",
    "12": "Flood",
    "13": "Rain-Flood",
}

awl = {
    "0": ("White", "Missing, insufficient, outdated or suspicious data."),
    "1": ("Green", "No particular awareness of the weather is required."),
    "2": (
        "Yellow",
        "The weather is potentially dangerous. The weather phenomena that have been forecast are not unusual, but be attentive if you intend to practice activities exposed to meteorological risks. Keep informed about the expected meteorological conditions and do not take any avoidable risk.",
    ),
    "3": (
        "Orange",
        "The weather is dangerous. Unusual meteorological phenomena have been forecast. Damage and casualties are likely to happen. Be very vigilant and keep regularly informed about the detailed expected meteorological conditions. Be aware of the risks that might be unavoidable. Follow any advice given by your authorities.",
    ),
    "4": (
        "Red",
        "The weather is very dangerous. Exceptionally intense meteorological phenomena have been forecast. Major damage and accidents are likely, in many cases with threat to life and limb, over a wide area. Keep frequently informed about detailed expected meteorological conditions and risks. Follow orders and any advice given by your authorities under all circumstances, be prepared for extraordinary measures.",
    ),
}


countries = {
    "AT": ("AT-Austria", "deutsch"),
    "BA": ("BA-Bosnia-Herzegovina", "/"),
    "BE": ("BE-Belgium", ""),
    "BG": ("BG-Bulgaria", ""),
    "CH": ("CH-Switzerland", "english"),
    "CY": ("CY-Cyprus", ""),
    "CZ": ("CZ-Czechia", "čeština"),
    "DE": ("DE-Germany", "deutsch"),
    "DK": ("DK-Denmark", ""),
    "EE": ("EE-Estonia", ""),
    "ES": ("ES-Spain", "español"),
    "FI": ("FI-Finland", "suomi"),
    "FR": ("FR-France", "français"),
    "GR": ("GR-Greece", "Ελληνικά"),
    "HR": ("HR-Croatia", "hrvatski"),
    "HU": ("HU-Hungary", ""),
    "IE": ("IE-Ireland", ""),
    "IL": ("IL-Israel", "עברית"),
    "IS": ("IS-Iceland", ""),
    "IT": ("IT-Italy", "italiano"),
    "LT": ("LT-Lithuania", "lietuviu"),
    "LU": ("LU-Luxembourg", ""),
    "LV": ("LV-Latvia", "latviešu"),
    "MD": ("MD-Moldova", ""),
    "ME": ("ME-Montenegro", "Црногорски"),
    "MK": ("MK-Republic%20of%20North%20Macedonia", ""),
    "MT": ("MT-Malta", "Malti"),
    "NL": ("NL-Netherlands", "nederlands"),
    "NO": ("NO-Norway", "norsk"),
    "PL": ("PL-Poland", "polski"),
    "PT": ("PT-Portugal", "português"),
    "RO": ("RO-Romania", ""),
    "RS": ("RS-Serbia", "српски"),
    "SE": ("SE-Sweden", ""),
    "SI": ("SI-Slovenia", "slovenščina"),
    "SK": ("SK-Slovakia", "slovenčina"),
    "UK": ("UK-United%20Kingdom", ""),
}
